@@ -35,7 +35,6 @@ if ($] >= 5.012 || ! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"cancer"} = "\x{264B}";
   $hash{"capricorn"} = "\x{2651}";
   $hash{"chains"} = "\x{26D3}\x{FE0F}";
-  $hash{"chess_pawn"} = "\x{265F}\x{FE0F}";
   $hash{"church"} = "\x{26EA}";
   $hash{"cloud"} = "\x{2601}\x{FE0F}";
   $hash{"clubs"} = "\x{2663}\x{FE0F}";
@@ -76,7 +75,6 @@ if ($] >= 5.012 || ! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"hotsprings"} = "\x{2668}\x{FE0F}";
   $hash{"hourglass"} = "\x{231B}";
   $hash{"ice_skate"} = "\x{26F8}\x{FE0F}";
-  $hash{"infinity"} = "\x{267E}\x{FE0F}";
   $hash{"information_source"} = "\x{2139}\x{FE0F}";
   $hash{"interrobang"} = "\x{2049}\x{FE0F}";
   $hash{"keyboard"} = "\x{2328}\x{FE0F}";
@@ -217,7 +215,6 @@ if ($] >= 5.014 || ! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"bee"} = "\x{1F41D}";
   $hash{"beer"} = "\x{1F37A}";
   $hash{"beers"} = "\x{1F37B}";
-  $hash{"beetle"} = "\x{1F41E}";
   $hash{"beginner"} = "\x{1F530}";
   $hash{"bell"} = "\x{1F514}";
   $hash{"bento"} = "\x{1F371}";
@@ -408,7 +405,7 @@ if ($] >= 5.014 || ! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"facepunch"} = "\x{1F44A}";
   $hash{"factory"} = "\x{1F3ED}";
   $hash{"fallen_leaf"} = "\x{1F342}";
-  $hash{"family"} = "\x{1F468}\x{200D}\x{1F469}\x{200D}\x{1F466}";
+  $hash{"family"} = "\x{1F46A}";
   $hash{"fast_forward"} = "\x{23E9}";
   $hash{"fax"} = "\x{1F4E0}";
   $hash{"fearful"} = "\x{1F628}";
@@ -806,6 +803,8 @@ if ($] >= 5.014 || ! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"koala"} = "\x{1F428}";
   $hash{"koko"} = "\x{1F201}";
   $hash{"kr"} = "\x{1F1F0}\x{1F1F7}";
+  $hash{"lady_beetle"} = "\x{1F41E}";
+  $hash{"ladybug"} = "\x{1F41E}";
   $hash{"lantern"} = "\x{1F3EE}";
   $hash{"large_blue_circle"} = "\x{1F535}";
   $hash{"large_blue_diamond"} = "\x{1F537}";
@@ -903,6 +902,7 @@ if ($] >= 5.014 || ! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"mega"} = "\x{1F4E3}";
   $hash{"melon"} = "\x{1F348}";
   $hash{"memo"} = "\x{1F4DD}";
+  $hash{"men-with-bunny-ears-partying"} = "\x{1F46F}\x{200D}\x{2642}\x{FE0F}";
   $hash{"men_holding_hands"} = "\x{1F46C}";
   $hash{"mens"} = "\x{1F6B9}";
   $hash{"metro"} = "\x{1F687}";
@@ -1275,6 +1275,7 @@ if ($] >= 5.014 || ! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"woman_and_man_holding_hands"} = "\x{1F46B}";
   $hash{"womans_clothes"} = "\x{1F45A}";
   $hash{"womans_hat"} = "\x{1F452}";
+  $hash{"women-with-bunny-ears-partying"} = "\x{1F46F}\x{200D}\x{2640}\x{FE0F}";
   $hash{"women_holding_hands"} = "\x{1F46D}";
   $hash{"womens"} = "\x{1F6BA}";
   $hash{"wrench"} = "\x{1F527}";
@@ -1374,7 +1375,6 @@ if ($] >= 5.022 || ! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"om_symbol"} = "\x{1F549}\x{FE0F}";
   $hash{"partly_sunny_rain"} = "\x{1F326}\x{FE0F}";
   $hash{"passenger_ship"} = "\x{1F6F3}\x{FE0F}";
-  $hash{"pirate_flag"} = "\x{1F3F4}\x{200D}\x{2620}\x{FE0F}";
   $hash{"printer"} = "\x{1F5A8}\x{FE0F}";
   $hash{"racing_car"} = "\x{1F3CE}\x{FE0F}";
   $hash{"racing_motorcycle"} = "\x{1F3CD}\x{FE0F}";
@@ -1514,7 +1514,6 @@ if ($] >= 5.026 || ! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"man-shrugging"} = "\x{1F937}\x{200D}\x{2642}\x{FE0F}";
   $hash{"man-wrestling"} = "\x{1F93C}\x{200D}\x{2642}\x{FE0F}";
   $hash{"man_dancing"} = "\x{1F57A}";
-  $hash{"man_in_tuxedo"} = "\x{1F935}";
   $hash{"martial_arts_uniform"} = "\x{1F94B}";
   $hash{"mother_christmas"} = "\x{1F936}";
   $hash{"motor_scooter"} = "\x{1F6F5}";
@@ -1525,6 +1524,7 @@ if ($] >= 5.026 || ! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"pancakes"} = "\x{1F95E}";
   $hash{"peanuts"} = "\x{1F95C}";
   $hash{"person_doing_cartwheel"} = "\x{1F938}";
+  $hash{"person_in_tuxedo"} = "\x{1F935}";
   $hash{"potato"} = "\x{1F954}";
   $hash{"pregnant_woman"} = "\x{1F930}";
   $hash{"prince"} = "\x{1F934}";
@@ -1559,8 +1559,6 @@ if ($] >= 5.026 || ! $ENV{SLACKEMOJI_STRICT}) {
 }
 if ($] >= 5.028 || ! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"adult"} = "\x{1F9D1}";
-  $hash{"artist"} = "\x{1F9D1}\x{200D}\x{1F3A8}";
-  $hash{"astronaut"} = "\x{1F9D1}\x{200D}\x{1F680}";
   $hash{"bearded_person"} = "\x{1F9D4}";
   $hash{"billed_cap"} = "\x{1F9E2}";
   $hash{"bowl_with_spoon"} = "\x{1F963}";
@@ -1572,7 +1570,6 @@ if ($] >= 5.028 || ! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"chopsticks"} = "\x{1F962}";
   $hash{"coat"} = "\x{1F9E5}";
   $hash{"coconut"} = "\x{1F965}";
-  $hash{"cook"} = "\x{1F9D1}\x{200D}\x{1F373}";
   $hash{"cricket"} = "\x{1F997}";
   $hash{"cup_with_straw"} = "\x{1F964}";
   $hash{"curling_stone"} = "\x{1F94C}";
@@ -1588,16 +1585,13 @@ if ($] >= 5.028 || ! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"face_with_open_mouth_vomiting"} = "\x{1F92E}";
   $hash{"face_with_raised_eyebrow"} = "\x{1F928}";
   $hash{"face_with_symbols_on_mouth"} = "\x{1F92C}";
-  $hash{"factory_worker"} = "\x{1F9D1}\x{200D}\x{1F3ED}";
   $hash{"fairy"} = "\x{1F9DA}";
-  $hash{"farmer"} = "\x{1F9D1}\x{200D}\x{1F33E}";
   $hash{"female_elf"} = "\x{1F9DD}\x{200D}\x{2640}\x{FE0F}";
   $hash{"female_fairy"} = "\x{1F9DA}\x{200D}\x{2640}\x{FE0F}";
   $hash{"female_genie"} = "\x{1F9DE}\x{200D}\x{2640}\x{FE0F}";
   $hash{"female_mage"} = "\x{1F9D9}\x{200D}\x{2640}\x{FE0F}";
   $hash{"female_vampire"} = "\x{1F9DB}\x{200D}\x{2640}\x{FE0F}";
   $hash{"female_zombie"} = "\x{1F9DF}\x{200D}\x{2640}\x{FE0F}";
-  $hash{"firefighter"} = "\x{1F9D1}\x{200D}\x{1F692}";
   $hash{"flying_saucer"} = "\x{1F6F8}";
   $hash{"fortune_cookie"} = "\x{1F960}";
   $hash{"genie"} = "\x{1F9DE}";
@@ -1605,10 +1599,8 @@ if ($] >= 5.028 || ! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"gloves"} = "\x{1F9E4}";
   $hash{"grinning_face_with_one_large_and_one_small_eye"} = "\x{1F92A}";
   $hash{"grinning_face_with_star_eyes"} = "\x{1F929}";
-  $hash{"health_worker"} = "\x{1F9D1}\x{200D}\x{2695}\x{FE0F}";
   $hash{"hedgehog"} = "\x{1F994}";
   $hash{"i_love_you_hand_sign"} = "\x{1F91F}";
-  $hash{"judge"} = "\x{1F9D1}\x{200D}\x{2696}\x{FE0F}";
   $hash{"mage"} = "\x{1F9D9}";
   $hash{"male_elf"} = "\x{1F9DD}\x{200D}\x{2642}\x{FE0F}";
   $hash{"male_fairy"} = "\x{1F9DA}\x{200D}\x{2642}\x{FE0F}";
@@ -1619,39 +1611,30 @@ if ($] >= 5.028 || ! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"man_climbing"} = "\x{1F9D7}\x{200D}\x{2642}\x{FE0F}";
   $hash{"man_in_lotus_position"} = "\x{1F9D8}\x{200D}\x{2642}\x{FE0F}";
   $hash{"man_in_steamy_room"} = "\x{1F9D6}\x{200D}\x{2642}\x{FE0F}";
-  $hash{"mechanic"} = "\x{1F9D1}\x{200D}\x{1F527}";
   $hash{"mermaid"} = "\x{1F9DC}\x{200D}\x{2640}\x{FE0F}";
   $hash{"merman"} = "\x{1F9DC}\x{200D}\x{2642}\x{FE0F}";
   $hash{"merperson"} = "\x{1F9DC}";
-  $hash{"office_worker"} = "\x{1F9D1}\x{200D}\x{1F4BC}";
   $hash{"older_adult"} = "\x{1F9D3}";
   $hash{"orange_heart"} = "\x{1F9E1}";
   $hash{"palms_up_together"} = "\x{1F932}";
-  $hash{"people_holding_hands"} = "\x{1F9D1}\x{200D}\x{1F91D}\x{200D}\x{1F9D1}";
   $hash{"person_climbing"} = "\x{1F9D7}";
   $hash{"person_in_lotus_position"} = "\x{1F9D8}";
   $hash{"person_in_steamy_room"} = "\x{1F9D6}";
   $hash{"person_with_headscarf"} = "\x{1F9D5}";
   $hash{"pie"} = "\x{1F967}";
-  $hash{"pilot"} = "\x{1F9D1}\x{200D}\x{2708}\x{FE0F}";
   $hash{"pretzel"} = "\x{1F968}";
   $hash{"sandwich"} = "\x{1F96A}";
   $hash{"sauropod"} = "\x{1F995}";
   $hash{"scarf"} = "\x{1F9E3}";
-  $hash{"scientist"} = "\x{1F9D1}\x{200D}\x{1F52C}";
   $hash{"serious_face_with_symbols_covering_mouth"} = "\x{1F92C}";
   $hash{"shocked_face_with_exploding_head"} = "\x{1F92F}";
   $hash{"shushing_face"} = "\x{1F92B}";
-  $hash{"singer"} = "\x{1F9D1}\x{200D}\x{1F3A4}";
   $hash{"sled"} = "\x{1F6F7}";
   $hash{"smiling_face_with_smiling_eyes_and_hand_covering_mouth"} = "\x{1F92D}";
   $hash{"socks"} = "\x{1F9E6}";
   $hash{"star-struck"} = "\x{1F929}";
-  $hash{"student"} = "\x{1F9D1}\x{200D}\x{1F393}";
   $hash{"t-rex"} = "\x{1F996}";
   $hash{"takeout_box"} = "\x{1F961}";
-  $hash{"teacher"} = "\x{1F9D1}\x{200D}\x{1F3EB}";
-  $hash{"technologist"} = "\x{1F9D1}\x{200D}\x{1F4BB}";
   $hash{"vampire"} = "\x{1F9DB}";
   $hash{"woman_climbing"} = "\x{1F9D7}\x{200D}\x{2640}\x{FE0F}";
   $hash{"woman_in_lotus_position"} = "\x{1F9D8}\x{200D}\x{2640}\x{FE0F}";
@@ -1663,6 +1646,8 @@ if ($] >= 5.028 || ! $ENV{SLACKEMOJI_STRICT}) {
 if ($] >= 5.030 || ! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"abacus"} = "\x{1F9EE}";
   $hash{"adhesive_bandage"} = "\x{1FA79}";
+  $hash{"artist"} = "\x{1F9D1}\x{200D}\x{1F3A8}";
+  $hash{"astronaut"} = "\x{1F9D1}\x{200D}\x{1F680}";
   $hash{"auto_rickshaw"} = "\x{1F6FA}";
   $hash{"axe"} = "\x{1FA93}";
   $hash{"badger"} = "\x{1F9A1}";
@@ -1681,8 +1666,10 @@ if ($] >= 5.030 || ! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"brown_heart"} = "\x{1F90E}";
   $hash{"butter"} = "\x{1F9C8}";
   $hash{"chair"} = "\x{1FA91}";
+  $hash{"chess_pawn"} = "\x{265F}\x{FE0F}";
   $hash{"cold_face"} = "\x{1F976}";
   $hash{"compass"} = "\x{1F9ED}";
+  $hash{"cook"} = "\x{1F9D1}\x{200D}\x{1F373}";
   $hash{"cupcake"} = "\x{1F9C1}";
   $hash{"curly_haired_man"} = "\x{1F468}\x{200D}\x{1F9B1}";
   $hash{"curly_haired_person"} = "\x{1F9D1}\x{200D}\x{1F9B1}";
@@ -1695,23 +1682,29 @@ if ($] >= 5.030 || ! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"dna"} = "\x{1F9EC}";
   $hash{"drop_of_blood"} = "\x{1FA78}";
   $hash{"ear_with_hearing_aid"} = "\x{1F9BB}";
+  $hash{"factory_worker"} = "\x{1F9D1}\x{200D}\x{1F3ED}";
   $hash{"falafel"} = "\x{1F9C6}";
+  $hash{"farmer"} = "\x{1F9D1}\x{200D}\x{1F33E}";
   $hash{"female_superhero"} = "\x{1F9B8}\x{200D}\x{2640}\x{FE0F}";
   $hash{"female_supervillain"} = "\x{1F9B9}\x{200D}\x{2640}\x{FE0F}";
   $hash{"fire_extinguisher"} = "\x{1F9EF}";
   $hash{"firecracker"} = "\x{1F9E8}";
+  $hash{"firefighter"} = "\x{1F9D1}\x{200D}\x{1F692}";
   $hash{"flamingo"} = "\x{1F9A9}";
   $hash{"flying_disc"} = "\x{1F94F}";
   $hash{"foot"} = "\x{1F9B6}";
   $hash{"garlic"} = "\x{1F9C4}";
   $hash{"goggles"} = "\x{1F97D}";
   $hash{"guide_dog"} = "\x{1F9AE}";
+  $hash{"health_worker"} = "\x{1F9D1}\x{200D}\x{2695}\x{FE0F}";
   $hash{"hiking_boot"} = "\x{1F97E}";
   $hash{"hindu_temple"} = "\x{1F6D5}";
   $hash{"hippopotamus"} = "\x{1F99B}";
   $hash{"hot_face"} = "\x{1F975}";
   $hash{"ice_cube"} = "\x{1F9CA}";
+  $hash{"infinity"} = "\x{267E}\x{FE0F}";
   $hash{"jigsaw"} = "\x{1F9E9}";
+  $hash{"judge"} = "\x{1F9D1}\x{200D}\x{2696}\x{FE0F}";
   $hash{"kangaroo"} = "\x{1F998}";
   $hash{"kite"} = "\x{1FA81}";
   $hash{"kneeling_person"} = "\x{1F9CE}";
@@ -1746,6 +1739,7 @@ if ($] >= 5.030 || ! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"mango"} = "\x{1F96D}";
   $hash{"manual_wheelchair"} = "\x{1F9BD}";
   $hash{"mate_drink"} = "\x{1F9C9}";
+  $hash{"mechanic"} = "\x{1F9D1}\x{200D}\x{1F527}";
   $hash{"mechanical_arm"} = "\x{1F9BE}";
   $hash{"mechanical_leg"} = "\x{1F9BF}";
   $hash{"microbe"} = "\x{1F9A0}";
@@ -1753,6 +1747,7 @@ if ($] >= 5.030 || ! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"mosquito"} = "\x{1F99F}";
   $hash{"motorized_wheelchair"} = "\x{1F9BC}";
   $hash{"nazar_amulet"} = "\x{1F9FF}";
+  $hash{"office_worker"} = "\x{1F9D1}\x{200D}\x{1F4BC}";
   $hash{"one-piece_swimsuit"} = "\x{1FA71}";
   $hash{"onion"} = "\x{1F9C5}";
   $hash{"orangutan"} = "\x{1F9A7}";
@@ -1762,11 +1757,14 @@ if ($] >= 5.030 || ! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"parrot"} = "\x{1F99C}";
   $hash{"partying_face"} = "\x{1F973}";
   $hash{"peacock"} = "\x{1F99A}";
+  $hash{"people_holding_hands"} = "\x{1F9D1}\x{200D}\x{1F91D}\x{200D}\x{1F9D1}";
   $hash{"person_in_manual_wheelchair"} = "\x{1F9D1}\x{200D}\x{1F9BD}";
   $hash{"person_in_motorized_wheelchair"} = "\x{1F9D1}\x{200D}\x{1F9BC}";
   $hash{"person_with_probing_cane"} = "\x{1F9D1}\x{200D}\x{1F9AF}";
   $hash{"petri_dish"} = "\x{1F9EB}";
+  $hash{"pilot"} = "\x{1F9D1}\x{200D}\x{2708}\x{FE0F}";
   $hash{"pinching_hand"} = "\x{1F90F}";
+  $hash{"pirate_flag"} = "\x{1F3F4}\x{200D}\x{2620}\x{FE0F}";
   $hash{"pleading_face"} = "\x{1F97A}";
   $hash{"probing_cane"} = "\x{1F9AF}";
   $hash{"raccoon"} = "\x{1F99D}";
@@ -1782,8 +1780,10 @@ if ($] >= 5.030 || ! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"safety_vest"} = "\x{1F9BA}";
   $hash{"salt"} = "\x{1F9C2}";
   $hash{"sari"} = "\x{1F97B}";
+  $hash{"scientist"} = "\x{1F9D1}\x{200D}\x{1F52C}";
   $hash{"service_dog"} = "\x{1F415}\x{200D}\x{1F9BA}";
   $hash{"shorts"} = "\x{1FA73}";
+  $hash{"singer"} = "\x{1F9D1}\x{200D}\x{1F3A4}";
   $hash{"skateboard"} = "\x{1F6F9}";
   $hash{"skunk"} = "\x{1F9A8}";
   $hash{"sloth"} = "\x{1F9A5}";
@@ -1793,9 +1793,12 @@ if ($] >= 5.030 || ! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"sponge"} = "\x{1F9FD}";
   $hash{"standing_person"} = "\x{1F9CD}";
   $hash{"stethoscope"} = "\x{1FA7A}";
+  $hash{"student"} = "\x{1F9D1}\x{200D}\x{1F393}";
   $hash{"superhero"} = "\x{1F9B8}";
   $hash{"supervillain"} = "\x{1F9B9}";
   $hash{"swan"} = "\x{1F9A2}";
+  $hash{"teacher"} = "\x{1F9D1}\x{200D}\x{1F3EB}";
+  $hash{"technologist"} = "\x{1F9D1}\x{200D}\x{1F4BB}";
   $hash{"teddy_bear"} = "\x{1F9F8}";
   $hash{"test_tube"} = "\x{1F9EA}";
   $hash{"thread"} = "\x{1F9F5}";
@@ -1817,4 +1820,121 @@ if ($] >= 5.030 || ! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"yawning_face"} = "\x{1F971}";
   $hash{"yo-yo"} = "\x{1FA80}";
 }
+if ($] >= 5.032 || ! $ENV{SLACKEMOJI_STRICT}) {
+  $hash{"accordion"} = "\x{1FA97}";
+  $hash{"anatomical_heart"} = "\x{1FAC0}";
+  $hash{"beaver"} = "\x{1F9AB}";
+  $hash{"beetle"} = "\x{1FAB2}";
+  $hash{"bell_pepper"} = "\x{1FAD1}";
+  $hash{"bison"} = "\x{1F9AC}";
+  $hash{"black_cat"} = "\x{1F408}\x{200D}\x{2B1B}";
+  $hash{"blueberries"} = "\x{1FAD0}";
+  $hash{"boomerang"} = "\x{1FA83}";
+  $hash{"bubble_tea"} = "\x{1F9CB}";
+  $hash{"bucket"} = "\x{1FAA3}";
+  $hash{"carpentry_saw"} = "\x{1FA9A}";
+  $hash{"cockroach"} = "\x{1FAB3}";
+  $hash{"coin"} = "\x{1FA99}";
+  $hash{"disguised_face"} = "\x{1F978}";
+  $hash{"dodo"} = "\x{1F9A4}";
+  $hash{"elevator"} = "\x{1F6D7}";
+  $hash{"feather"} = "\x{1FAB6}";
+  $hash{"flatbread"} = "\x{1FAD3}";
+  $hash{"fly"} = "\x{1FAB0}";
+  $hash{"fondue"} = "\x{1FAD5}";
+  $hash{"headstone"} = "\x{1FAA6}";
+  $hash{"hook"} = "\x{1FA9D}";
+  $hash{"hut"} = "\x{1F6D6}";
+  $hash{"knot"} = "\x{1FAA2}";
+  $hash{"ladder"} = "\x{1FA9C}";
+  $hash{"long_drum"} = "\x{1FA98}";
+  $hash{"lungs"} = "\x{1FAC1}";
+  $hash{"magic_wand"} = "\x{1FA84}";
+  $hash{"mammoth"} = "\x{1F9A3}";
+  $hash{"man_feeding_baby"} = "\x{1F468}\x{200D}\x{1F37C}";
+  $hash{"man_in_tuxedo"} = "\x{1F935}\x{200D}\x{2642}\x{FE0F}";
+  $hash{"man_with_veil"} = "\x{1F470}\x{200D}\x{2642}\x{FE0F}";
+  $hash{"military_helmet"} = "\x{1FA96}";
+  $hash{"mirror"} = "\x{1FA9E}";
+  $hash{"mouse_trap"} = "\x{1FAA4}";
+  $hash{"mx_claus"} = "\x{1F9D1}\x{200D}\x{1F384}";
+  $hash{"nesting_dolls"} = "\x{1FA86}";
+  $hash{"ninja"} = "\x{1F977}";
+  $hash{"olive"} = "\x{1FAD2}";
+  $hash{"people_hugging"} = "\x{1FAC2}";
+  $hash{"person_feeding_baby"} = "\x{1F9D1}\x{200D}\x{1F37C}";
+  $hash{"pickup_truck"} = "\x{1F6FB}";
+  $hash{"pinata"} = "\x{1FA85}";
+  $hash{"pinched_fingers"} = "\x{1F90C}";
+  $hash{"placard"} = "\x{1FAA7}";
+  $hash{"plunger"} = "\x{1FAA0}";
+  $hash{"polar_bear"} = "\x{1F43B}\x{200D}\x{2744}\x{FE0F}";
+  $hash{"potted_plant"} = "\x{1FAB4}";
+  $hash{"rock"} = "\x{1FAA8}";
+  $hash{"roller_skate"} = "\x{1F6FC}";
+  $hash{"screwdriver"} = "\x{1FA9B}";
+  $hash{"seal"} = "\x{1F9AD}";
+  $hash{"sewing_needle"} = "\x{1FAA1}";
+  $hash{"smiling_face_with_tear"} = "\x{1F972}";
+  $hash{"tamale"} = "\x{1FAD4}";
+  $hash{"teapot"} = "\x{1FAD6}";
+  $hash{"thong_sandal"} = "\x{1FA74}";
+  $hash{"toothbrush"} = "\x{1FAA5}";
+  $hash{"transgender_flag"} = "\x{1F3F3}\x{FE0F}\x{200D}\x{26A7}\x{FE0F}";
+  $hash{"transgender_symbol"} = "\x{26A7}\x{FE0F}";
+  $hash{"window"} = "\x{1FA9F}";
+  $hash{"woman_feeding_baby"} = "\x{1F469}\x{200D}\x{1F37C}";
+  $hash{"woman_in_tuxedo"} = "\x{1F935}\x{200D}\x{2640}\x{FE0F}";
+  $hash{"woman_with_veil"} = "\x{1F470}\x{200D}\x{2640}\x{FE0F}";
+  $hash{"wood"} = "\x{1FAB5}";
+  $hash{"worm"} = "\x{1FAB1}";
+}
+if ($] >= 5.035004 || ! $ENV{SLACKEMOJI_STRICT}) {
+  $hash{"beans"} = "\x{1FAD8}";
+  $hash{"biting_lip"} = "\x{1FAE6}";
+  $hash{"bubbles"} = "\x{1FAE7}";
+  $hash{"coral"} = "\x{1FAB8}";
+  $hash{"crutch"} = "\x{1FA7C}";
+  $hash{"dotted_line_face"} = "\x{1FAE5}";
+  $hash{"empty_nest"} = "\x{1FAB9}";
+  $hash{"face_holding_back_tears"} = "\x{1F979}";
+  $hash{"face_with_diagonal_mouth"} = "\x{1FAE4}";
+  $hash{"face_with_open_eyes_and_hand_over_mouth"} = "\x{1FAE2}";
+  $hash{"face_with_peeking_eye"} = "\x{1FAE3}";
+  $hash{"hamsa"} = "\x{1FAAC}";
+  $hash{"hand_with_index_finger_and_thumb_crossed"} = "\x{1FAF0}";
+  $hash{"heart_hands"} = "\x{1FAF6}";
+  $hash{"heavy_equals_sign"} = "\x{1F7F0}";
+  $hash{"identification_card"} = "\x{1FAAA}";
+  $hash{"index_pointing_at_the_viewer"} = "\x{1FAF5}";
+  $hash{"jar"} = "\x{1FAD9}";
+  $hash{"leftwards_hand"} = "\x{1FAF2}";
+  $hash{"lotus"} = "\x{1FAB7}";
+  $hash{"low_battery"} = "\x{1FAAB}";
+  $hash{"melting_face"} = "\x{1FAE0}";
+  $hash{"mirror_ball"} = "\x{1FAA9}";
+  $hash{"nest_with_eggs"} = "\x{1FABA}";
+  $hash{"palm_down_hand"} = "\x{1FAF3}";
+  $hash{"palm_up_hand"} = "\x{1FAF4}";
+  $hash{"person_with_crown"} = "\x{1FAC5}";
+  $hash{"playground_slide"} = "\x{1F6DD}";
+  $hash{"pouring_liquid"} = "\x{1FAD7}";
+  $hash{"pregnant_man"} = "\x{1FAC3}";
+  $hash{"pregnant_person"} = "\x{1FAC4}";
+  $hash{"rightwards_hand"} = "\x{1FAF1}";
+  $hash{"ring_buoy"} = "\x{1F6DF}";
+  $hash{"saluting_face"} = "\x{1FAE1}";
+  $hash{"troll"} = "\x{1F9CC}";
+  $hash{"wheel"} = "\x{1F6DE}";
+  $hash{"x-ray"} = "\x{1FA7B}";
+}
+if (! $ENV{SLACKEMOJI_STRICT}) {
+  $hash{"face_exhaling"} = "\x{1F62E}\x{200D}\x{1F4A8}";
+  $hash{"face_in_clouds"} = "\x{1F636}\x{200D}\x{1F32B}\x{FE0F}";
+  $hash{"face_with_spiral_eyes"} = "\x{1F635}\x{200D}\x{1F4AB}";
+  $hash{"heart_on_fire"} = "\x{2764}\x{FE0F}\x{200D}\x{1F525}";
+  $hash{"man_with_beard"} = "\x{1F9D4}\x{200D}\x{2642}\x{FE0F}";
+  $hash{"mending_heart"} = "\x{2764}\x{FE0F}\x{200D}\x{1FA79}";
+  $hash{"woman_with_beard"} = "\x{1F9D4}\x{200D}\x{2640}\x{FE0F}";
+}
 return \%hash;
